clear matrix
clear
capture log close
set more off
macro drop _all
set memory 1G  // Jae: you might wanna also increase the memory.
set more off
set matsize 500

set linesize 255
//set maxvar 30000

// Jae: You should change the below directory. 
//global maindirectory ="C:\Users\Serdar\Documents\My Dropbox\GREAT-RECESSION\Data_Serdar"
//global maindirectory ="/a/foflx1/lcl/fof/home/m1sxo00/RESEARCH/GREAT-RECESSION/Data_Serdar"
global maindirectory ="C:\Research\GREAT-RECESSION\Stata"

global Jae=0  // Jae: Please change this variable to 1 when you run the code. 
global unix=0  // JAE: Please change this to 1 if you run stata on Unix or Mac
if($unix==1){
	global sep="/"
}
else{
	global sep="\"
}


// YOU DON'T NEED TO MAKE ANY CHANGES FROM THIS POINT ON!!!!

global outfolder=c(current_date)
global outfolder="$outfolder AggStatWage7811"
//global outfolder="27 Jan 2012 Factor"
capture noisily mkdir "$maindirectory${sep}out${sep}$outfolder"
capture noisily log using "$maindirectory${sep}log${sep}$outfolder.log", replace
cd "$maindirectory${sep}out${sep}$outfolder"

do "$maindirectory${sep}do${sep}bymydiststat.do"

global yrfirst = 1978 		// First year in the dataset
global yrlast = 2011 		// Last year in the dataset
global begin_age = 25 
global retire_age = 60
global numq = 100		// Number of quintiles

global JMPpercentiles= "1 5 10 25 50 75 90 95 99"
global AGGpercentiles= "p1 p5 p10 p25 p50 p75 p90 p95 p99"
global inclist="wage" // Income list that we analyze
global varoi="wage" // Income list that we analyze

global base_price = 59   /* this is the index of the year 2005 */

matrix cpimat = /*  CPI for 1947-2012
*/ (14.126,14.926,14.811,14.989, /*
*/ 16.009,16.337,16.556,16.697,16.764,17.101,17.620,18.035,18.306,18.606, /*
*/ 18.801,19.023,19.245,19.527,19.810,20.313,20.824,21.636,22.616,23.674, /*
*/ 24.681,25.525,26.901,29.703,32.184,33.950,36.155,38.687,42.118,46.642, /*
*/ 50.810,53.615,55.923,58.038,59.938,61.399,63.589,66.121,68.994,72.147, /*
*/ 74.755,76.955,78.643,80.265,82.041,83.826,85.395,86.207,87.596,89.778, /*
*/ 91.489,92.736,94.622,97.098,100.000,102.746,105.564,109.061,109.258, /*
*/ 111.05,113.790,115.784)

matrix minwg = /* Nominal minimum wage 1947-2012
*/ (0.40,0.40,0.40,0.40,0.75,0.75,0.75,0.75,0.75,1.00,1.00,1.00,1.00,1.00, /*
*/ 1.00,1.15,1.15,1.25,1.25,1.25,1.25,1.40,1.60,1.60,1.60,1.60,1.60,1.60, /*
*/ 2.00,2.10,2.10,2.30,2.65,2.90,3.10,3.35,3.35,3.35,3.35,3.35,3.35,3.35, /*
*/ 3.35,3.35,3.80,4.25,4.25,4.25,4.25,4.25,4.75,5.15,5.15,5.15,5.15,5.15, /*
*/ 5.15,5.15,5.15,5.15,5.15,5.85,6.55,7.25,7.25,7.25)

matrix rmininc = J(rowsof(minwg),colsof(minwg), 0.0)
forvalues yr = 1947/2012{
	local cpi_index = `yr'-1947+1
	local deflate = cpimat[1,$base_price]/cpimat[1,`cpi_index']
	matrix rmininc[1,`cpi_index']=40*13*0.5*minwg[1,`cpi_index']*`deflate'
}

global basla=c(current_time)

use "$maindirectory${sep}dta${sep}cleaned_male_10p_SIC_WAGE_SELFINC_7811", clear

matrix avg${varoi}m = J($yrlast-$yrfirst+1,1, 0.0)
global mean${varoi}all=0
local N${varoi}=0
forvalues yr = $yrfirst/$yrlast{

	replace wage`yr'=. if selfinc`yr'>= rmininc[1,`yr'-1947+1] & selfinc`yr'~=.
	drop selfinc`yr'
	
	qui sum ${varoi}`yr', meanonly
	matrix avg${varoi}m[`yr'-$yrfirst+1,1]=r(mean)
	
	global mean${varoi}all = ${mean${varoi}all} + r(mean)*r(N)
	local N${varoi}=`N${varoi}' + r(N)
}
global mean${varoi}all = ${mean${varoi}all}/`N${varoi}'
global logmean${varoi}all=log(${mean${varoi}all})

mac list mean${varoi}all logmean${varoi}all

svmat avg${varoi}m, names("y_bar")
outsheet y_bar if y_bar ~=. using avgagg${varoi}.txt, replace
drop y_bar


gen year=.
foreach var in $inclist{
	gen log${varoi}1978=log(${varoi}1978)  if ${varoi}1978>=rmininc[1,1978-1947+1] & ${varoi}1978~=.
	gen log${varoi}1979=log(${varoi}1979) if ${varoi}1979>=rmininc[1,1979-1947+1] & ${varoi}1979~=.
	gen log${varoi}1980=log(${varoi}1980) if ${varoi}1980>=rmininc[1,1980-1947+1] & ${varoi}1980~=.
	gen log${varoi}1981=log(${varoi}1981) if ${varoi}1981>=rmininc[1,1981-1947+1] & ${varoi}1981~=.
	gen log${varoi}1982=log(${varoi}1982) if ${varoi}1982>=rmininc[1,1982-1947+1] & ${varoi}1982~=.
	forvalues yr = $yrfirst/$yrlast{
		replace year=`yr'	
		local varM="log${varoi}"
		local prefix="AL"
		local suffix="yr"
		global statlist1 ="`prefix'N`varM'`suffix'=r(N) `prefix'mean`varM'`suffix'=r(mean) `prefix'sd`varM'`suffix'=r(sd)"
		global statlist2 ="`prefix'skew`varM'`suffix'=r(skewness) `prefix'kurt`varM'`suffix'=r(kurtosis) `prefix'min`varM'`suffix'=r(min)" 
		global statlist3 ="`prefix'max`varM'`suffix'=r(max) `prefix'p1`varM'`suffix'=r(p1) `prefix'p5`varM'`suffix'=r(p5) `prefix'p10`varM'`suffix'=r(p10)"
		global statlist4 ="`prefix'p25`varM'`suffix'=r(p25) `prefix'p50`varM'`suffix'=r(p50) `prefix'p75`varM'`suffix'=r(p75) "
		global statlist5 ="`prefix'p90`varM'`suffix'=r(p90) `prefix'p95`varM'`suffix'=r(p95) `prefix'p99`varM'`suffix'=r(p99)"
		qui statsby $statlist1 $statlist2 $statlist3 $statlist4 $statlist5 , by(year) saving(`prefix'`varM'`yr',replace):  summarize `varM'`yr',detail
		
		qui statsby `prefix'mean${varoi}`suffix'=r(mean), by(year) saving(`prefix'${varoi}`yr',replace):  summarize ${varoi}`yr' if ${varoi}`yr'>=rmininc[1,`yr'-1947+1] & ${varoi}`yr'~=. ,meanonly
							
		
		if(`yr'<=$yrlast-1){
			local yrn1=`yr'+1		
			gen tempL1=log${varoi}`yrn1'-log${varoi}`yr' 
			
			local varM="log${varoi}"
			local prefix="L1"
			local suffix="yr"
			global statlist1 ="`prefix'N`varM'`suffix'=r(N) `prefix'mean`varM'`suffix'=r(mean) `prefix'sd`varM'`suffix'=r(sd)"
			global statlist2 ="`prefix'skew`varM'`suffix'=r(skewness) `prefix'kurt`varM'`suffix'=r(kurtosis) `prefix'min`varM'`suffix'=r(min)" 
			global statlist3 ="`prefix'max`varM'`suffix'=r(max) `prefix'p1`varM'`suffix'=r(p1) `prefix'p5`varM'`suffix'=r(p5) `prefix'p10`varM'`suffix'=r(p10)"
			global statlist4 ="`prefix'p25`varM'`suffix'=r(p25) `prefix'p50`varM'`suffix'=r(p50) `prefix'p75`varM'`suffix'=r(p75) "
			global statlist5 ="`prefix'p90`varM'`suffix'=r(p90) `prefix'p95`varM'`suffix'=r(p95) `prefix'p99`varM'`suffix'=r(p99)"
			qui statsby $statlist1 $statlist2 $statlist3 $statlist4 $statlist5 , by(year) saving(`prefix'`varM'`yr',replace):  summarize tempL1,detail
			
			drop tempL1
		}
		if(`yr'<=$yrlast-5){
			local yrn5=`yr'+5
			gen log${varoi}`yrn5'=log(${varoi}`yrn5')  if ${varoi}`yrn5'>=rmininc[1,`yrn5'-1947+1] & ${varoi}`yrn5'~=.	
			gen tempL5=log${varoi}`yrn5'-log${varoi}`yr' 
			
			local varM="log${varoi}"
			local prefix="L5"
			local suffix="yr"
			global statlist1 ="`prefix'N`varM'`suffix'=r(N) `prefix'mean`varM'`suffix'=r(mean) `prefix'sd`varM'`suffix'=r(sd)"
			global statlist2 ="`prefix'skew`varM'`suffix'=r(skewness) `prefix'kurt`varM'`suffix'=r(kurtosis) `prefix'min`varM'`suffix'=r(min)" 
			global statlist3 ="`prefix'max`varM'`suffix'=r(max) `prefix'p1`varM'`suffix'=r(p1) `prefix'p5`varM'`suffix'=r(p5) `prefix'p10`varM'`suffix'=r(p10)"
			global statlist4 ="`prefix'p25`varM'`suffix'=r(p25) `prefix'p50`varM'`suffix'=r(p50) `prefix'p75`varM'`suffix'=r(p75) "
			global statlist5 ="`prefix'p90`varM'`suffix'=r(p90) `prefix'p95`varM'`suffix'=r(p95) `prefix'p99`varM'`suffix'=r(p99)"
			qui statsby $statlist1 $statlist2 $statlist3 $statlist4 $statlist5 , by(year) saving(`prefix'`varM'`yr',replace):  summarize tempL5,detail	
			
			drop tempL5
		}
		drop log${varoi}`yr'
	}
}
foreach var in $inclist{
	capture noisily drop _all
	use ALlog${varoi}$yrfirst.dta
	erase ALlog${varoi}$yrfirst.dta
	
	merge year using AL${varoi}$yrfirst.dta, update
	drop _merge
	erase AL${varoi}$yrfirst.dta
	
	local yrn=$yrfirst+1
	forvalues yr = `yrn'/$yrlast{
		append using ALlog${varoi}`yr'.dta 
		erase ALlog${varoi}`yr'.dta 
		sort year
		merge year using AL${varoi}`yr'.dta, update
		drop _merge
		erase AL${varoi}`yr'.dta		
	}
	outsheet using AggLevel${varoi}.txt, replace
	
	capture noisily drop _all
	use L1log${varoi}$yrfirst.dta
	erase L1log${varoi}$yrfirst.dta
	local yrn=$yrfirst+1
	local yrl=$yrlast-1		
	forvalues yr = `yrn'/`yrl'{
		append using L1log${varoi}`yr'.dta 
		erase L1log${varoi}`yr'.dta 					
	}
	outsheet using AggDiffL1${varoi}.txt, replace
	
	capture noisily drop _all
	use L5log${varoi}$yrfirst.dta
	erase L5log${varoi}$yrfirst.dta
	local yrn=$yrfirst+1
	local yrl=$yrlast-5		
	forvalues yr = `yrn'/`yrl'{
		append using L5log${varoi}`yr'.dta 
		erase L5log${varoi}`yr'.dta 					
	}
	outsheet using AggDiffL5${varoi}.txt, replace
}	

capture noisily log close
global bit=c(current_time)
macro list basla bit
