clear matrix
clear
capture log close
set more off
macro drop _all
set memory 1G  // Jae: you might wanna also increase the memory.
set more off
set matsize 500

set linesize 255
//set maxvar 30000

// Jae: You should change the below directory. 
//global maindirectory ="C:\Users\Serdar\Documents\My Dropbox\GREAT-RECESSION\Data_Serdar"
global maindirectory ="/a/foflx1/lcl/fof/home/m1sxo00/RESEARCH/GREAT-RECESSION/Data_Serdar"
global Jae=0  // Jae: Please change this variable to 1 when you run the code. 
global unix=1  // JAE: Please change this to 1 if you run stata on Unix or Mac

// Jae: Make sure you put the following do files in the do folder; o/w specify their location accordingly! 

// YOU DON'T NEED TO MAKE ANY CHANGES FROM THIS POINT ON!!!!

// Please change the dataset name
//global datafile_10p ="AR1_150K10P.dta" // Jae: Change the name of the data file to the 10% sample

global labor=0
if($unix==1){
	global sep="/"
}
else{
	global sep="\"
}
// Please change the dataset name
global datafile_10p ="AR1_150K10P.dta" // Jae: Change the name of the data file to the 10% sample

// YOU DON'T NEED TO MAKE ANY CHANGES FROM THIS POINT ON!!!!
global outfolder=c(current_date)
global outfolder="$outfolder DJMP_DP_WAGE"
capture noisily mkdir "$maindirectory${sep}out${sep}$outfolder"
cd "$maindirectory${sep}out${sep}$outfolder"

capture noisily log using "$outfolder.log", replace

global DJMP_DP_short="$maindirectory${sep}do${sep}DJMP_DP_short.do"
do "$maindirectory${sep}do${sep}bymydiststat.do"
do "$maindirectory${sep}do${sep}bymyxtile.do"

global yrfirst = 1978 		// First year in the dataset
global yrlast = 2010 		// Last year in the dataset
global begin_age = 25 
global retire_age = 60
global minobspr = 9		// Minimum number of observations  pre-recession 
global numq = 100		// Number of quintiles

global JMPpercentiles= "1 5 10 25 50 75 90 95 99"
global AGGpercentiles= "p1 p5 p10 p25 p50 p75 p90 p95 p99"
global inclist="wage" // Income list that we analyze
global varoi="wage" // Income list that we analyze

global base_price = 59   /* this is the index of the year 2005 */
global basla=c(current_time)
matrix cpimat = /*  CPI for 1947-2010
*/ (14.126,14.926,14.811,14.989, /*
*/ 16.009,16.337,16.556,16.697,16.764,17.101,17.620,18.035,18.306,18.606, /*
*/ 18.801,19.023,19.245,19.527,19.810,20.313,20.824,21.636,22.616,23.674, /*
*/ 24.681,25.525,26.901,29.703,32.184,33.950,36.155,38.687,42.118,46.642, /*
*/ 50.810,53.615,55.923,58.038,59.938,61.399,63.589,66.121,68.994,72.147, /*
*/ 74.755,76.955,78.643,80.265,82.041,83.826,85.395,86.207,87.596,89.778, /*
*/ 91.489,92.736,94.622,97.098,100.000,102.746,105.564,109.061,109.258,111.0501)

matrix minwg = /* Nominal minimum wage 1947-2010
*/ (0.40,0.40,0.40,0.40,0.75,0.75,0.75,0.75,0.75,1.00,1.00,1.00,1.00,1.00, /*
*/ 1.00,1.15,1.15,1.25,1.25,1.25,1.25,1.40,1.60,1.60,1.60,1.60,1.60,1.60, /*
*/ 2.00,2.10,2.10,2.30,2.65,2.90,3.10,3.35,3.35,3.35,3.35,3.35,3.35,3.35, /*
*/ 3.35,3.35,3.80,4.25,4.25,4.25,4.25,4.25,4.75,5.15,5.15,5.15,5.15,5.15, /*
*/ 5.15,5.15,5.15,5.15,5.15,5.85,6.55,7.25)

matrix rmininc = J(rowsof(minwg),colsof(minwg), 0.0)
forvalues yr = 1947/2010{
	local cpi_index = `yr'-1947+1
	local deflate = cpimat[1,$base_price]/cpimat[1,`cpi_index']
	matrix rmininc[1,`cpi_index']=40*13*0.5*minwg[1,`cpi_index']*`deflate'
}

capture noisily drop _all
use "$maindirectory${sep}dta${sep}$datafile_10p"
keep id wage*  sic1_* yob yod male selfinc*
destring, replace force

display "***********************************"
display "Male Sample"
display "***********************************"
drop if male~=1
	
drop male	
drop if yob==.
drop if $yrfirst-yob+1>$retire_age | $yrlast-yob+1<$begin_age 
drop if yod<=$yrfirst & yod~=.
count

forvalues yr = $yrfirst/$yrlast{
	rename sic1_`yr' sic`yr'	
	replace wage`yr' = 0 if wage`yr'==.
	replace selfinc`yr' = 0 if selfinc`yr'==.
}
foreach var in wage selfinc{ 
	forvalues yr = $yrfirst/$yrlast{
		gen temp`var'=`var'`yr' if `yr'-yob+1>= $begin_age & `yr'- yob+1<= $retire_age & `yr'< yod  // yod=. id very big number  
		egen temp=pctile(temp`var'), p(99.999)
		replace `var'`yr'= temp if `var'`yr'>=temp
		drop temp temp`var'
		
		local cpi_index = `yr'-1947+1
		local deflate = cpimat[1,$base_price]/cpimat[1,`cpi_index']
		replace `var'`yr' = `var'`yr'*`deflate'
		
		gen temp=uniform()-0.5
		replace `var'`yr'=`var'`yr'+`var'`yr'*temp/5000 
		drop temp
		
		replace `var'`yr'= . if `yr'-yob+1 < $begin_age | `yr'- yob+1>$retire_age 
		replace `var'`yr'= . if `yr'>= yod & yod~=.  // (yod=. is very big number)
	}
}
compress
save "$maindirectory${sep}dta${sep}cleaned_male_10p_SIC_WAGE_SELFINC", replace

// ************************************************************************************************	
//	Coefficients of Age Dummies Using 1% Sample
// ************************************************************************************************	
drop sic*
gen sampling=runiform()
drop if sampling>0.10
drop sampling

reshape long wage selfinc, i(id) j(year)

gen age= year-yob+1
drop if age < $begin_age | age > $retire_age 
drop if yod<=year & yod~=. // Drop the dead.

gen rminincvar=rmininc[1,year-1947+1]
drop if selfinc>=rminincvar & selfinc~=. 
drop selfinc

tab age, gen(agedum)
tab yob, gen(cohdum)

local cohmax= ($yrlast-$begin_age+1) -($yrfirst-$retire_age+1) +1 
local yrmax= ($yrlast-$yrfirst) +1 

gen templog${varoi} = log(${varoi}) if ${varoi}>=rminincvar
regress templog${varoi} agedum* cohdum2-cohdum`cohmax', nocons
matrix bc=get(_b)
matrix agedum${varoi}=bc[1,1..$retire_age-$begin_age+1]
forvalues i = $begin_age/$retire_age{
	matrix agedum${varoi}[1,`i'-$begin_age+1]=exp(agedum${varoi}[1,`i'-$begin_age+1])
}	
drop temp*
matrix bc=(agedum${varoi})'
svmat bc, name(meanagenocoh${varoi})
egen printtag=tag(meanagenocoh${varoi})
outsheet meanagenocoh${varoi} using meanagenocoh${varoi}dummy.txt if printtag==1, replace
drop printtag meanagenocoh${varoi}*
matrix drop bc 	

capture noisily log close
// ************************************************************************************************	
//	Individual Factor Structure
// ************************************************************************************************	

global yrbpr=1978
global yrepr=1978		
global yrbr=1979
global yrer=1983
global minobspr=1
do "$DJMP_DP_short"

global yrbpr=1985
global yrepr=1989		
global yrbr=1990
global yrer=1992
global minobspr=3
do "$DJMP_DP_short"

global yrbpr=1995
global yrepr=1999		
global yrbr=2000
global yrer=2002
global minobspr=3	
do "$DJMP_DP_short"

global yrbpr=2002
global yrepr=2006		
global yrbr=2007
global yrer=2010
global minobspr=3	
do "$DJMP_DP_short"

global yrbpr=1979
global yrepr=1983		
global yrbr=1984
global yrer=1986
global minobspr=3	
do "$DJMP_DP_short"

global yrbpr=1989
global yrepr=1993		
global yrbr=1994
global yrer=1996
global minobspr=3	
do "$DJMP_DP_short"

global yrbpr=1999
global yrepr=2003		
global yrbr=2004
global yrer=2006
global minobspr=3	
do "$DJMP_DP_short"



