drop _all
use "$maindirectory${sep}dta${sep}cleaned_male_10p_SIC_WAGE_SELFINC"
drop sic*

global DJMPfolder="DJMP_DP$yrbr$yrer"
capture noisily mkdir "$maindirectory${sep}out${sep}$outfolder${sep}$DJMPfolder"
global logname="$maindirectory${sep}out${sep}$outfolder${sep}$DJMPfolder${sep}DJMP_DPreg.log"
capture noisily log using "$logname", replace
cd "$maindirectory${sep}out${sep}$outfolder${sep}$DJMPfolder"


local yrdrop=$yrbpr-1 
forvalues yr = $yrfirst/`yrdrop'{  
	foreach var in wage selfinc{
		drop `var'`yr'
	}
}
local yrdrop1=$yrbr+1
local yrdrop2=$yrer-1
forvalues yr = `yrdrop1'/`yrdrop2'{  
	foreach var in wage selfinc{
		drop `var'`yr'
	}
}
local yrdrop=$yrer+1
forvalues yr = `yrdrop'/$yrlast{  
	foreach var in wage selfinc{
		drop `var'`yr'
	}
}

drop if yob > $yrepr -$begin_age +1 
drop if yob < $yrer -$retire_age +1
drop if yod <= $yrer & yod~=.	

forvalues yr = $yrbpr/$yrbr{
	drop if selfinc`yr'>= rmininc[1,`yr'-1947+1] & selfinc`yr'~=.
	drop selfinc`yr'
}  

drop if selfinc$yrer>= rmininc[1,$yrer-1947+1] & selfinc$yrer~=.
drop selfinc$yrer
	

gen age$yrepr = $yrepr-yob+1 if yob<=$yrepr & yod>= $yrepr
drop yod

gen agebin$yrepr = .

local bin=1
forvalues h = $begin_age(5)$retire_age{
	replace agebin$yrepr = `bin' if age$yrepr>=`h' & age$yrepr<min(`h'+5,$retire_age)	
	local bin=`bin' +1
}
qui sum agebin$yrepr
local bin=r(max)
replace agebin$yrepr = `bin'  if age$yrepr==$retire_age

matrix avgagedum${varoi}=J(1,$retire_age-$begin_age+1,0)
local dura = $yrepr-$yrbpr+1
local hmax = $retire_age-$begin_age+1
forvalues i=1/`hmax'{
	local dura1=min(`i',`dura')-1
	forvalues j=0/`dura1'{
		matrix avgagedum${varoi}[1,`i']	= avgagedum${varoi}[1,`i'] + agedum${varoi}[1,`i'-`j']
	}
	matrix avgagedum${varoi}[1,`i']	= ln(avgagedum${varoi}[1,`i']/(`dura1'+1))
}

gen pastinc=.
gen pastincind=0
gen  avg${varoi}$yrepr=0
gen  numallobs${varoi}$yrepr=0
gen  numobs${varoi}$yrepr=0
replace numobs${varoi}$yrepr=-5 if ${varoi}$yrepr < rmininc[1,$yrepr-1947+1] | ${varoi}$yrepr==.
forvalues t =$yrbpr/$yrepr{	
	replace avg${varoi}$yrepr=avg${varoi}$yrepr +max(${varoi}`t', rmininc[1,`t'-1947+1]) if ${varoi}`t'~=.
	replace numobs${varoi}$yrepr=numobs${varoi}$yrepr +1 if ${varoi}`t' >= rmininc[1,`t'-1947+1] & ${varoi}`t'~=.
	replace numallobs${varoi}$yrepr=numallobs${varoi}$yrepr +1 if ${varoi}`t'~=.	
	replace pastinc=${varoi}`t'  if ${varoi}`t' >= rmininc[1,`t'-1947+1] & ${varoi}`t'~=. &	pastincind==0 & `t'< $yrepr
	replace pastincind=1  if ${varoi}`t' >= rmininc[1,`t'-1947+1] & ${varoi}`t'~=. & `t'< $yrepr
}
replace avg${varoi}$yrepr = avg${varoi}$yrepr/numallobs${varoi}$yrepr if numobs${varoi}$yrepr >=$minobspr
replace avg${varoi}$yrepr = . if numobs${varoi}$yrepr < $minobspr 
replace avg${varoi}$yrepr = ln(avg${varoi}$yrepr) - avgagedum${varoi}[1,age$yrepr-$begin_age+1] if numobs${varoi}$yrepr >=$minobspr
rename avg${varoi}$yrepr avgres${varoi}$yrepr 
if($yrepr>$yrfirst){
	gen delta${varoi}$yrepr=log(${varoi}$yrepr)-log(pastinc) if ${varoi}$yrepr >= rmininc[1,$yrepr-1947+1] & ${varoi}$yrepr~=.
}
else{
	gen delta${varoi}$yrepr=log(${varoi}1979)-log(${varoi}$yrepr) if ${varoi}1979 >= rmininc[1,1979-1947+1] & ${varoi}1979~=. & ///
								${varoi}$yrepr >= rmininc[1,$yrepr-1947+1] & ${varoi}$yrepr~=.
}
drop numobs${varoi}$yrepr numallobs${varoi}$yrepr pastinc pastincind

gen res${varoi}$yrbr= agedum${varoi}[1,1]*${varoi}$yrbr/agedum${varoi}[1,$yrbr-yob+1-24]
gen res${varoi}$yrer= agedum${varoi}[1,1]*${varoi}$yrer/agedum${varoi}[1,$yrer-yob+1-24]

gen delta$yrepr=.
gen avginc=.
global numq=50
qui bys agebin$yrepr: bymyxtile avgres${varoi}$yrepr avginc
global numq=40
qui bys agebin$yrepr: bymyxtile delta${varoi}$yrepr delta$yrepr

by agebin$yrepr: egen binnobs=count(avgres${varoi}$yrepr)
replace binnobs=0.20*binnobs/(40*50)

gen nonzero${varoi}$yrbr=1 if ${varoi}$yrbr>rmininc[1,$yrbr-1947+1] 
gen nonzero${varoi}$yrer=1 if ${varoi}$yrer>rmininc[1,$yrer-1947+1] 

sort agebin$yrepr avginc delta$yrepr
by agebin$yrepr avginc delta$yrepr: egen avgres${varoi}$yrbr=mean(res${varoi}$yrbr)
by agebin$yrepr avginc delta$yrepr: egen avgres${varoi}$yrer=mean(res${varoi}$yrer)

by agebin$yrepr avginc delta$yrepr: egen N${varoi}$yrbr=count(nonzero${varoi}$yrbr)
by agebin$yrepr avginc delta$yrepr: egen N${varoi}$yrer=count(nonzero${varoi}$yrer)

replace avgres${varoi}$yrbr=. if N${varoi}$yrbr<binnobs
replace avgres${varoi}$yrer=. if N${varoi}$yrer<binnobs

gen logavgresincch = log(avgres${varoi}$yrer)-log(avgres${varoi}$yrbr)

tab delta$yrepr, gen(delta${yrepr}dum)
tab avginc, gen(avgincdum)

egen regtag=tag(agebin$yrepr avginc delta$yrepr)

qui statsby _b _se r(r2),  by(agebin$yrepr) saving(reg_logavgincch_avginc_delta,replace): reg logavgresincch avgincdum* delta${yrepr}dum* if regtag==1, nocons
qui statsby  _b _se r(sum_adev) r(sum_rdev), by(agebin$yrepr) saving(qreg_logavgincch_avginc_delta,replace): qreg logavgresincch avgincdum* delta${yrepr}dum* if regtag==1

drop delta$yrepr avginc delta${yrepr}dum* avgincdum* ///
nonzero${varoi}$yrbr nonzero${varoi}$yrer avgres${varoi}$yrbr avgres${varoi}$yrer ///
N${varoi}$yrbr N${varoi}$yrer logavgresincch regtag binnobs

gen avginc=.
global numq=100
qui bys agebin$yrepr: bymyxtile avgres${varoi}$yrepr avginc

sort agebin$yrepr avginc

by agebin$yrepr avginc: egen avgres${varoi}$yrbr=mean(res${varoi}$yrbr)
by agebin$yrepr avginc: egen avgres${varoi}$yrer=mean(res${varoi}$yrer)

gen logavgresincch = log(avgres${varoi}$yrer)-log(avgres${varoi}$yrbr)

tab avginc, gen(avgincdum)

egen regtag=tag(agebin$yrepr avginc)

qui statsby _b _se r(r2),  by(agebin$yrepr) saving(reg_logavgincch_avginc,replace): reg logavgresincch avgincdum*  if regtag==1, nocons

drop _all
use reg_logavgincch_avginc
erase reg_logavgincch_avginc.dta
outsheet using coeff_reg_logavgincch_avginc.txt, replace

drop _all
use reg_logavgincch_avginc_delta
erase reg_logavgincch_avginc_delta.dta
outsheet using coeff_reg_logavgincch_avginc_delta.txt, replace

drop _all
use qreg_logavgincch_avginc_delta
erase qreg_logavgincch_avginc_delta.dta
outsheet using coeff_qreg_logavgincch_avginc_delta.txt, replace

capture noisily log close

